#
# spec file for package htop
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           htop
Version:        3.0.5
Release:        lp152.4.4.1
Summary:        An Interactive text-mode Process Viewer for Linux
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://htop.dev
Source0:        https://dl.bintray.com/%{name}/source/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(hwloc)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(ncurses)
Recommends:     lsof
Recommends:     strace
%ifnarch        s390 s390x
BuildRequires:  libsensors4-devel
%endif

%description
htop is an interactive text-mode process viewer for Linux. It aims to be a
better 'top' and requires ncurses.

%prep
%autosetup -p1

%build
%configure \
  --enable-taskstats \
  --enable-unicode \
  --enable-hwloc \
  --enable-taskstats \
  --enable-delayacct \
  --enable-cgroup
%make_build

%install
%make_install
%suse_update_desktop_file -i %{name} System Monitor

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}.1%{?ext_man}
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/scalable/
%dir %{_datadir}/icons/hicolor/scalable/apps/
%{_datadir}/icons/hicolor/scalable/apps/htop.svg

%changelog
* Tue Jan 12 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.0.5:
  * InfoScreen: fix uncontrolled format string
  * Improve white text in the Light Terminal colour scheme
  * Enable the function bar on the main screen to be hidden (see Setup -> Display options)
  * Reduce layout issues esp. around printing wide characters (not complete yet)
  * Make the follow function exit cleanly after followed process died
  * Update help and man page for improved -t / -s options
  * Drop usage of formatted error messages from <err.h>
  * Show arrow indicating order of sorted process column
  * Lots of plumbing around the internal Hashtable, hardening and code cleanups
  * LibSensors: add support for Ryzen CPUs
  * Fix CPU percentage on M1 silicon Macs
  * LoadMeter: dynamically adjust color and total of bar
  * Find libsensors.so.4 for Fedora and friends
  * Enable going back to previous search matches (Shift-F3)
  * Added keybind 'N' for sorting by PID (drops 'n'/'N' as not used before much)
* Wed Dec 23 2020 Andreas Stieger <andreas.stieger@gmx.de>
- htop 3.0.4:
  * Separate tree and list sort orders
  * PSI Meter: constant width and only print ten-duration as bar
  * Sort in paused mode after inverting sort order
  * Handle absence of package CPU temperature
  * Document dynamic bindings and assumed external configuration
  * Update key mapping documentation for sorting
* Mon Dec  7 2020 Michael Ströder <michael@stroeder.com>
- Update to version 3.0.3
  * Process sorting in 'tree' mode
  * Improved command display/sort functionality
  * Add screen for active file locks
  * Calculate library size (M_LRS column) from maps file
  * Add a Zram meter
  * Add Linux cwd process column
  * Dynamically load libsensors at runtime
  * Improve PressureStall Meter display strings
  * Hide process selection on ESC
  * Fully support non-ascii characters in Meter-Bar
  * Add support to change numeric options in settings screen
  * Rename virtual memory column from M_SIZE to M_VIRT
  * Add process column for normalized CPU usage
  * Show CPU temperature in CPU meter
  * Drop hideThreads Setting
  * Add a systemd meter
  * Add a network IO meter
  * Add a SELinux meter
  * Compress size of default FunctionBar
  * Updates to the OpenFiles screen
  * Continue updating header data in paused mode
  * BUGFIX: Handle data wraparounds in IO meters
  * BUGFIX: Update InfoScreen content on resize
  * Add security attribute process column
  * Add DiskIOMeter for IO read/write usage
  * Read CPU frequency from sysfs by default
  * Add Linux process column for context switches
  * Several FreeBSD and Mac OS X platform updates
  * Add process environment for FreeBSD
  * Parse POWER_SUPPLY_CAPACITY for Linux Battery meter
  * Add octuple-column CPU meters.
  * BUGFIX: On Linux consider ZFS ARC to be cache
  * BUGFIX: Limit screen title length to window width
  * Show selected command wrapped in a separate window
  * Allow to pass '/' for item search
  * Document implicit incremental search
  * Handle 'q' as quit if first character
  * Avoid expensive build of process tree when not using it
  * Include documentation for COMM and EXE
  * Distinguish display of no permissions for reading M_LRS
  * Only calculate M_LRS size every 2 seconds
  * Improvements to comm / cmdline display functionality
  * Merged view for COMM, EXE and cmdline
    (thanks to Narendran Gopalakrishnan and Benny Baumann)
  * Consistent kernel thread display for COMM/EXE columns
  * Central fault handling for all platforms
  * Handle parsing envID & VPid from process status file
  * Use threshold for display of guest/steal/irq meters
  * Enhance highlighting of semi-large and large numbers
  * Documentation on the repository style guide
  * Align processor identifier to the right
  * Document M_PSS, M_PSSWP, M_SWAP in man page
  * Add Date and DateTime meters
  * BUGFIX: Fix Solaris 11.4 due to missing ZFS ARC kstats
  * Code hardening, speedups, fd and memory leak fixes
  * Number CPUs from zero by default
  * Remove residual python checks during the build process
* Tue Sep 15 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 3.0.2
  * BUGFIX: Drop 'vim_mode' - several issues, needs rethink
  * BUGFIX: fix regression in -u optional-argument handling
  * Build system rework to remove python, header generation
  * CI, code quality improvements
- Switch to new official bintray tarball to remove automake deps
* Sun Sep  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.1
  * BUGFIX: Fix early exit with longer sysfs battery paths
  * BUGFIX: Improve OOM output, fix sorting
  * Rework check buttons and tree open/closed
  * Add -U/--no-unicode option to disable unicode
  * Improvements to the affinity panel
* Sat Aug 29 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 3.0.0
  * Add simple, optional vim key mapping mode
  * Support more than 2 smaller CPU meter columns
  * Support Linux proportional set size metrics
  * Support Linux pressure stall information metrics
  * New display option to show CPU frequency in CPU meters
  * Update Linux sysfs battery discovery for recent kernels
  * Add hardware topology information in the affinity panel
  * Add timestamp reporting to the strace screen
  * Added an option to disable the mouse
  * Without an argument -u uses $USER value automatically
  * Support less(1) search navigation shortcuts
  * Support ZFS ARC statistics
  * Report values larger than 100 terabytes
  * Widen ST_UID (UID) column to allow for UIDs > 9999
  * BUGFIX: fix makefiles for building with clang
  * BUGFIX: fix <sys/sysmacros.h> major() usage
  * BUGFIX: correctly identify other types of zombie process
  * BUGFIX: improve follow-process handling in some situations
  * BUGFIX: fix custom meters reverting to unexpected setting
  * BUGFIX: close pipe after running lsof(1)
  * BUGFIX: meters honour setting of counting CPUs from 0/1
- Drop htop-2.2.0.tar.gz.asc - no sig provided
- Upstreamed patches removed:
  * Drop htop-2.2.0-fix-linux-process-ordering.patch
  * Drop htop-2.2.0-fix-option-string.patch
  * Drop htop-2.2.0-gcc10.patch
  * Drop htop-desktop-file-fix-thoenig-01.patch
  * Drop htop-script-python3.patch
* Fri Jun  5 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10:
  * htop-2.2.0-gcc10.patch
* Thu Apr 23 2020 Martin Pluskal <mpluskal@suse.com>
- Add patches:
  * htop-2.2.0-fix-linux-process-ordering.patch
  * htop-2.2.0-fix-option-string.patch (fixes boo#1165352)
* Thu Apr 12 2018 mpluskal@suse.com
- Simplify spec file
  * Drop support for building on older distros
  * Trim describtion
- Enable delayacct
* Tue Apr 10 2018 avindra@opensuse.org
- Update to version 2.2.0
  * -t/--tree flag for starting in tree-view mode
  * Various automake and build improvements
  * Check for pkg-config when building with --enable-delayacct
  * Avoid some bashisms in configure script
  * Use CFLAGS from ncurses*-config if present
  * Header generator supports non-UTF-8 environments
  * Changed detection of kernel threads
  * Collapse current subtree pressing Backspace
  * BUGFIX: fix behavior of SYSCR column
  * BUGFIX: obtain exit code of lsof correctly
  * BUGFIX: fix crash with particular keycodes
  * BUGFIX: fix issue with small terminals
  * BUGFIX: fix terminal color issues
  * BUGFIX: preserve LDFLAGS when building
  * BUGFIX: fixed overflow for systems with >= 100 signals
- cleanup with spec-cleaner
- rebase htop-script-python3.patch
* Fri Feb 23 2018 ecsos@opensuse.org
- fix build error for Leap 42.3
* Tue Feb  6 2018 mpluskal@suse.com
- Small cleanup with spec-clener
* Mon Feb  5 2018 aloisio@gmx.com
- Update to version 2.1.0
  * Linux: Delay accounting metrics
    (thanks to André Carvalho)
  * Support for real-time signals
    (thanks to Kang-Che Sung)
  * 'c' key now works with threads as well
  * Session column renamed from SESN to SID
    (thanks to Kamyar Rasta)
  * Improved UI for meter style selection
    (thanks to Kang-Che Sung)
  * Improved code for constructing process tree
    (thanks to wangqr)
  * Compile-time option to disable setuid
  * Error checking of various standard library operations
  * Replacement of sprintf with snprintf
    (thanks to Tomasz Kramkowski)
  * Linux: performance improvements in battery meter
  * Linux: update process TTY device
  * Linux: add support for sorting TASK_IDLE
    (thanks to Vladimir Panteleev)
  * Linux: add upper-bound to running process counter
    (thanks to Lucas Correia Villa Real)
  * BUGFIX: avoid crash when battery is removed
    (thanks to Jan Chren)
- Refreshed htop-desktop-file-fix-thoenig-01.patch
- Added htop-script-python3.patch
* Mon Jan  2 2017 mpluskal@suse.com
- Add gpg signature
* Mon Oct 24 2016 mpluskal@suse.com
- Small spec file cleanup
* Sat Jul 23 2016 mpluskal@suse.com
- Update to version 2.0.2:
  * Mac OS X: stop trying when task_for_pid fails for a process,
    stops spamming logs with errors.
  * Add Ctrl+A and Ctrl+E to go to beginning and end of line
  * FreeBSD: fixes for CPU calculation
  * Usability: auto-follow process after a search.
  * Use Linux backend on GNU Hurd
  * Improvement for reproducible builds.
  * BUGFIX: Fix behavior of Alt-key combinations
  * Various code tweaks and cleanups
- Drop htop-2.0.1-fix-escdelay-usage.patch
- Update htop-desktop-file-fix-thoenig-01.patch
- Drop some build dependencies
- Enable taskstats
* Sun May 22 2016 develop7@develop7.info
- added upstream patch fixing ESCDELAY-related build failure on modern ncurses
  (htop-2.0.1-fix-escdelay-usage.patch)
- updated configure script parameters
* Fri May 13 2016 develop7@develop7.info
- Update to v2.0.1
  * OpenBSD: Various fixes and improvements (thanks to Michael McConville and
    Juan Francisco Cantero Hurtado)
  * FreeBSD: fix CPU and memory readings (thanks to Tim Creech, Hung-Yi Chen,
    Bernard Spil, Greg V)
  * FreeBSD: add battery support (thanks to Greg V)
  * Linux: Retain last-obtained name of a zombie process
  * Mac OS X: Improve portability for OS X versions (thanks to Michael Klein)
  * Mac OS X: Fix reading command-line arguments and basename
  * Mac OS X: Fix process state information
  * Mac OS X: Fix tree view collapsing/expanding
  * Mac OS X: Fix tree organization
  * Mac OS X: Fix memory accounting
  * Fix crash when emptying a column of meters
  * Make Esc key more responsive
- removed htop-2.0.0-fix-buffer-reuse.patch and htop-stdgnu.patch
* Thu Mar  3 2016 develop7@develop7.info
- htop-2.0.0-fix-buffer-reuse.patch: upstream fix for crash with SIGABRT
* Thu Feb 11 2016 jimmy@boombatower.com
- Update to version 2.0.0.
  * Platform abstraction layer
  * Initial FreeBSD support
  * Initial Mac OS X support (thanks to David Hunt)
  * Swap meter for Mac OSX (thanks to Ștefan Rusu)
  * OpenBSD port (thanks to Michael McConville)
  * FreeBSD support improvements (thanks to Martin Misuth)
  * Support for NCurses 6 ABI, including mouse wheel support
  * Much improved mouse responsiveness
  * Process environment variables screen (thanks to Michael Klein)
  * Higher-resolution UTF-8 based Graph mode (Thanks to James Hall from vtop for the idea!)
  * Show program path settings (thanks to Tobias Geerinckx-Rice)
  * BUGFIX: Fix crash when scrolling an empty filtered list.
  * Use dynamic units for text display, and several fixes (thanks to Christian Hesse)
  * BUGFIX: fix error caused by overflow in usertime calculation. (thanks to Patrick Marlier)
  * Catch all memory allocation errors (thanks to Michael McConville for the push)
  * Several tweaks and bugfixes (See the Git log for details and contributors!)
- Rerolled both patches for compatibility with 2.0.0.
- Fix ncurses 6 incompatibility during compile.
* Sun Aug  2 2015 mpluskal@suse.com
- Add scriplets for desktop file handling
* Fri Feb 20 2015 jhura@suse.com
- Cleanup of spec file with spec-cleaner.
- Enable oom score watching and native-affinity
* Mon May 19 2014 dmitry_r@opensuse.org
- Update to version 1.0.3
  * Tag all children ('c' key)
  * Fixes in accounting of guest time when using virtualization
  * Performance improvements
  * Further performance improvements due to conditional parsing
    of IO data depending on selected fields.
  * Better consistency in coloring.
  * Increase limit of buffer when tracing a deep nested process tree.
  * Display pagefault stats.
  * BUGFIX: Fix crash when adding meters and toggling detailed CPU time.
  * Add column to track the OOM-killer score of processes
  * Rebase htop-stdgnu.patch
* Thu Dec 26 2013 crrodriguez@opensuse.org
- improve autools build, we do not want packages
  using, for example std=c99, instead determine the
  latest C standard with gnu extensions using autoconf macros.
  (htop-stdgnu.patch)
* Tue Nov 26 2013 jengelh@inai.de
- Better make install, remove %%clean
* Mon Nov 12 2012 puzel@suse.com
- update to htop-1.0.2
  * Add IO priority support ('i' key)
  * Avoid deleting .htoprc if it is a symlink
  * Fail gracefully when /proc is not mounted
    (thanks to Philipp Hagemeister)
  * Option to update process names on every refresh
    (thanks to Rob Hoelz)
  * BUGFIX: Fix crashes when process list is empty
* Fri Feb 17 2012 puzel@suse.com
- update to htop-1.0.1 (bugfix release)
  * respecting $XDG_CONFIG_HOME
    (thanks to Hadzhimurad Ustarkhan for the suggestion.)
  * Safer behavior on the kill screen, to make it harder to kill
    the wrong process.
  * BUGFIX: behavior of 'F' (follow) key was broken, also affecting
    the persistence of mouse selections.
  * BUGFIX: keep main panel up-to-date when running the screen
    manager, to fix crash when processes die while on the F9/Kill
    screen.
* Thu Nov 24 2011 puzel@suse.com
- update to htop-1.0
  * Performance improvements
  * Support for splitting CPU meters into two or four columns
  * Switch from PLPA, which is now deprecated, to HWLOC.
  * Bring back support for native Linux sched_setaffinity,
    so we don't have to use HWLOC where we don't need to.
  * Support for typing in user names and column fields in selection
    panels.
  * Support for UTF-8 tree drawing
  * Option for counting CPUs from zero
  * Meters update in every screen (no longer halting while on
    Setup, etc.)
  * Stricter checks for command-line options
  * Incremental filtering
  * Try harder to find the ncurses header
  * Man page updates
  * BUGFIX: Support larger numbers for process times.
  * BUGFIX: Segfault in BarMeterMode_draw() for small terminal
    widths
* Sat Jul 30 2011 crrodriguez@opensuse.org
- Use --enable-unicode and switch to ncurses ABI v6
* Mon Nov 29 2010 puzel@novell.com
- update to htop-0.9
  * Add support for "steal"/guest CPU time measurement
    in virtualization environments
  * Expand and collapse subtrees using '+' and '-' when in tree-view
  * Support for cgroups
  * Show custom thread names
  * Add support for STARTTIME field
  * Upgrade PLPA to version 1.3.2
  * Fix license terms with regard to PLPA
  * getopt-based long options and --no-color
  * BUGFIX: Fix display of nan%% in CPU meters
  * BUGFIX: Fix memory leak
  * Add Bash/emacs style navigation keys
  * Improve battery meter support
  * BUGFIX: Fix IO-wait color in "Black on White" scheme
  * BUGFIX: Fix search by process name when list is filtered by
    user.
  * BUGFIX: Fix alignment for display of memory values above 100G
- drop htop-non-printable-characters.patch (in upstream)
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Dec 14 2009 jengelh@medozas.de
- enable parallel building
* Wed Jun 24 2009 puzel@novell.com
- update to htop-0.8.3
  * BUGFIX: Fix crash on F6 key (thanks to Rainer Suhm)
  * BUGFIX: Fix a minor bug which affected the build process.
* Tue Jun  2 2009 puzel@suse.cz
- update to 0.8.2
  * Integrated lsof (press 'l')
  * Fix display of gigabyte-sized values
  * Option to display hostname in the meters area
  * Rename VEID to CTID in OpenVZ systems
  * Corrections to the desktop entry file
  * BUGFIX: Correct page size calculation for FreeBSD systems
  * Allow compilation without PLPA on systems that don't support it
  * BUGFIX: Fix missing tree view when userland threads are hidden
  * BUGFIX: Fix for VPID on OpenVZ systems
- Recommends strace and lsof
- use suse_update_desktop_file macro
* Fri Nov 21 2008 thoenig@suse.de
- add python to build requires
* Fri Nov 21 2008 thoenig@suse.de
- add patch htop-non-printable-characters.patch: Don't try to show
  non-printable charcaters (bnc#440951)
* Tue Sep 23 2008 thoenig@suse.de
- Linux-VServer support
- battery meter
- fix collection of IO stats in multithreaded processes
- remove assertion that fails on hardened kernels
* Thu Jul 31 2008 puzel@suse.cz
- configure with --enable-taskstats to enable
  per-processes IO statistics
- use %%configure and %%makeinstall macros
* Fri Jul 11 2008 bwalle@suse.de
- update to htop 0.8
  * Ability to change sort column with the mouse by clicking
    column titles (click again to invert order)
  * Add support for Linux per-process IO statistics, enabled with
    the --enable-taskstats flag, which requires a kernel compiled
    with taskstats support.
  * Add Unicode support, enabled with the --enable-unicode flag,
    which requires libncursesw.  (thanks to Sergej Pupykin)
  * BUGFIX: Fix display of CPU count for threaded processes.  When
    user threads are hidden, process now shows the sum of
    processor usage for all processors. When user threads are
    displayed, each thread shows its own processor usage,
    including the root thread.
  * BUGFIX: avoid crashing when using many meters
- change source tarball format to bzip2
* Mon Nov 26 2007 thoenig@suse.de
- Update to htop 0.7
- Changes:
  * CPU affinity configuration ('a' key)
  * Improve display of tree view, properly nesting
  threads of the same app based on TGID.
  * IO-wait time now counts as idle time, which is a more
  accurate description. It is still available in
  split time, now called detailed CPU time.
  (thanks to Samuel Thibault for the report)
  * BUGFIX: Correct display of TPGID field
  * Add TGID field
  * BUGFIX: Don't crash with invalid command-line flags
  (thanks to Nico Golde for the report)
  * Fix GCC 4.3 compilation issues
  (thanks to Martin Michlmayr for the report)
  * OpenVZ support, enabled at compile-time with
  the --enable-openvz flag.
  (thanks to Sergey Lychko)
* Sat Jun  2 2007 thoenig@suse.de
- Update to htop 0.6.6
- Changes:
  * Add support of NLWP field
  * BUGFIX: Fix use of configurable /proc location
  * Fix memory percentage calculation and make it saner
  * Added display of DRS, DT, LRS and TRS
  * BUGFIX: LRS and DRS memory values were flipped
  * BUGFIX: Don't crash on very high UIDs
* Tue May 22 2007 thoenig@suse.de
- Initial package submission (htop 0.6.5)
- Add patch htop-desktop-file-fix-thoenig-01.patch
